Struct sgf_parse::ParseOptions [−][src]
pub struct ParseOptions {
pub allow_conversion: bool,
}Expand description
Options for parsing SGF files.
Fields
allow_conversion: boolWhether to allow conversion of FF[3] mixed case identifiers to FF[4].
This should allow parsing any older files which are valid, but not valid FF[4]. Note that this doesn’t attempt to perform any further conversions as suggested here. Beyond accepting mixed case identifiers, conversion is left to the application author.